@@ -160,7 +160,7 @@ impl XorMappedAddress {
 
         let family = u16::from_be_bytes([v[0], v[1]]);
         if family != FAMILY_IPV6 && family != FAMILY_IPV4 {
-            return Err(Error::ErrOthers(format!("bad value {}", family)).into());
+            return Err(Error::new(format!("bad value {}", family)).into());
         }
 
         check_overflow(
